@@ -138,14 +138,16 @@ def validate_spec(spec):
 
 
 def find_config_files(metadata_or_path, additional_files=None, ignore_system_config=False,
-                      exclusive_config_file=None):
+                      exclusive_config_files=None):
     """Find files to load variables from.  Note that order here determines clobbering.
 
     Later files clobber earlier ones.  order is user-wide < cwd < recipe dir < additional files"""
-    files = ([os.path.abspath(os.path.expanduser(exclusive_config_file))]
-             if exclusive_config_file else [])
+    files = [
+        os.path.abspath(os.path.expanduser(config_file))
+        for config_file in (exclusive_config_files or [])
+    ]
 
-    if not ignore_system_config and not exclusive_config_file:
+    if not ignore_system_config and not exclusive_config_files:
         if cc_conda_build.get('config_file'):
             system_path = abspath(expanduser(expandvars(cc_conda_build['config_file'])))
         else:
@@ -479,7 +481,7 @@ def get_package_variants(recipedir_or_metadata, config=None, variants=None):
         config = Config()
     files = find_config_files(recipedir_or_metadata, ensure_list(config.variant_config_files),
                               ignore_system_config=config.ignore_system_variants,
-                              exclusive_config_file=config.exclusive_config_file)
+                              exclusive_config_files=config.exclusive_config_files)
 
     specs = OrderedDict(internal_defaults=get_default_variant(config))
 
@@ -531,13 +533,13 @@ def get_vars(variants, loop_only=False):
 
 
 @memoized
-def find_used_variables_in_text(variant, recipe_text):
+def find_used_variables_in_text(variant, recipe_text, selectors=False):
     used_variables = set()
     recipe_lines = recipe_text.splitlines()
     for v in variant:
         all_res = []
         compiler_match = re.match(r'(.*?)_compiler$', v)
-        if compiler_match:
+        if compiler_match and not selectors:
             compiler_lang = compiler_match.group(1)
             compiler_regex = (
                 r"\{\s*compiler\([\'\"]%s[\"\'][^\{]*?\}" % re.escape(compiler_lang)
@@ -549,12 +551,16 @@ def find_used_variables_in_text(variant, recipe_text):
         if not variant_lines:
             continue
         v_regex = re.escape(v)
+        v_req_regex = '[-_]'.join(map(re.escape, v.split('_')))
         variant_regex = r"\{\s*(?:pin_[a-z]+\(\s*?['\"])?%s[^'\"]*?\}\}" % v_regex
         selector_regex = r"^[^#\[]*?\#?\s\[[^\]]*?(?<![_\w\d])%s[=\s<>!\]]" % v_regex
         conditional_regex = r"(?:^|[^\{])\{%\s*(?:el)?if\s*" + v_regex + r"\s*(?:[^%]*?)?%\}"
         # plain req name, no version spec.  Look for end of line after name, or comment or selector
-        requirement_regex = r"^\s+\-\s+%s\s*(?:\s[\[#]|$)" % v_regex.replace('_', '[-_]')
-        all_res.extend([variant_regex, selector_regex, conditional_regex, requirement_regex])
+        requirement_regex = r"^\s+\-\s+%s\s*(?:\s[\[#]|$)" % v_req_regex
+        if selectors:
+            all_res.extend([selector_regex])
+        else:
+            all_res.extend([variant_regex, requirement_regex, conditional_regex])
         # consolidate all re's into one big one for speedup
         all_res = r"|".join(all_res)
         if any(re.search(all_res, line) for line in variant_lines):
